@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojo::ByteStream 'b';
 use Mojo::URL;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # Todo: Update to https://tools.ietf.org/html/rfc6570
 # Todo: Allow for changing scheme, port, host etc. afterwards
@@ -183,10 +183,10 @@ Mojolicious::Plugin::Util::Endpoint - Use template URIs in Mojolicious
   # Mojolicious::Lite
   plugin 'Util::Endpoint';
 
-  my $r = $mojo->routes;
+  my $rs = $mojo->routes;
 
   # Set endpoint
-  $r->route('/:user')->endpoint(
+  $r = $rs->route('/:user')->endpoint(
     webfinger => {
       query  => [
         q => '{uri}'
@@ -234,7 +234,7 @@ Called when registering the plugin.
 =head2 C<endpoint>
 
   my $r = $mojo->routes
-  $r->route('/suggest')->endpoint(opensearch => {
+  $r = $r->route('/suggest')->endpoint(opensearch => {
     scheme => 'https',
     host   => 'sojolicio.us',
     port   => 3000,
@@ -252,6 +252,9 @@ Template parameters need curly brackets, optional
 template parameters need a question mark before
 the closing bracket.
 Optional path placeholders are currenty not supported.
+This also defines a name attribute to the route for
+using with C<url_for>.
+Returns the route.
 
 
 =head1 HELPERS
